@@ -2,6 +2,19 @@
 ### BiocParallelParam objects
 ### -------------------------------------------------------------------------
 
+.BiocParallelParam_prototype <- list(
+    workers=0,
+    tasks=0L,
+    jobname="BPJOB",
+    catch.errors=TRUE,    ## deprecated
+    log=FALSE,
+    threshold="INFO",
+    stop.on.error=TRUE,
+    timeout=30L * 24L * 60L * 60L, # 30 days
+    exportglobals=TRUE,
+    progressbar=FALSE
+)
+
 .BiocParallelParam <- setRefClass("BiocParallelParam",
     contains="VIRTUAL",
     fields=list(
@@ -14,27 +27,11 @@
         threshold="character",
         stop.on.error="logical",
         timeout="integer",
+        exportglobals="logical",
         ## deprecated
         catch.errors="logical"
     ),
     methods=list(
-        initialize = function(..., 
-            workers=0, 
-            tasks=0L, 
-            jobname="BPJOB",
-            catch.errors=TRUE,    ## deprecated
-            log=FALSE,
-            threshold="INFO",
-            stop.on.error=TRUE,
-            timeout= 30L * 24L * 60L * 60L, # 30 days
-            progressbar=FALSE)
-        {
-            callSuper(...)
-            initFields(workers=workers, tasks=tasks, jobname=jobname, 
-                       catch.errors=catch.errors, log=log, threshold=threshold,
-                       stop.on.error=stop.on.error, timeout=as.integer(timeout),
-                       progressbar=progressbar)
-        },
         show = function() {
             cat("class: ", class(.self),
                 "\n",
@@ -49,6 +46,7 @@
                 "\n",
                 "  bptimeout: ", bptimeout(.self),
                 "; bpprogressbar: ", bpprogressbar(.self),
+                "; bpexportglobals: ", bpexportglobals(.self),
                 "\n", sep="")
         })
 )
@@ -80,6 +78,9 @@ setValidity("BiocParallelParam", function(object)
             msg <- c(msg, "number of tasks is less than number of workers")
     }
 
+    if (!.isTRUEorFALSE(bpexportglobals(object)))
+        msg <- c(msg, "'bpexportglobals' must be TRUE or FALSE")
+
     ## error handling
     if (!.isTRUEorFALSE(bpcatchErrors(object)))
         msg <- c(msg, "'catch.errors' must be TRUE or FALSE")
@@ -98,7 +99,7 @@ setValidity("BiocParallelParam", function(object)
     }
 
     if (!.isTRUEorFALSE(bpstopOnError(object)))
-        msg <- c(msg, "'bpstopOnError(BPPARAM)' must be logical(1)")
+        msg <- c(msg, "'bpstopOnError' must be logical(1)")
 
     if (is.null(msg)) TRUE else msg
 })
@@ -164,6 +165,20 @@ setReplaceMethod("bptimeout", c("BiocParallelParam", "numeric"),
     x
 })
 
+setMethod("bpexportglobals", "BiocParallelParam",
+    function(x)
+{
+    x$exportglobals
+})
+
+setReplaceMethod("bpexportglobals", c("BiocParallelParam", "logical"),
+    function(x, value)
+{
+    x$exportglobals <- value
+    validObject(x)
+    x
+})
+
 setMethod("bpstopOnError", "BiocParallelParam",
     function(x)
 {
