@@ -28,7 +28,7 @@ bptry <- function(expr, ..., bplist_error, bperror)
 .composeTry <- function(FUN, log, stop.on.error,
                         stop.immediate = FALSE, # TRUE for SerialParam lapply
                         as.error = TRUE,        # FALSE for BatchJobs compatible
-                        timeout)
+                        timeout, exportglobals = TRUE)
 {
     if (!stop.on.error && stop.immediate)
         stop("[internal] 'stop.on.error == FALSE' && 'stop.immediate == TRUE'")
@@ -39,6 +39,17 @@ bptry <- function(expr, ..., bplist_error, bperror)
     force(stop.immediate)
     force(as.error)
     force(timeout)
+    if (exportglobals) {
+        blacklist <- c(
+            "askpass", "asksecret", "buildtools.check",
+            "buildtools.with", "pager", "plumber.swagger.url",
+            "profvis.print", "restart", "reticulate.repl.hook",
+            "reticulate.repl.initialize", "reticulate.repl.teardown",
+            "shiny.launch.browser", "terminal.manager", "error"
+        )
+        global_options <- base::options()
+        global_options <- global_options[!names(global_options) %in% blacklist]
+    }
 
     ERROR_OCCURRED <- FALSE
     UNEVALUATED <- .error_unevaluated() # singleton
@@ -66,6 +77,9 @@ bptry <- function(expr, ..., bplist_error, bperror)
         setTimeLimit(timeout, timeout, TRUE)
         on.exit(setTimeLimit(Inf, Inf, FALSE))
 
+        if (exportglobals)
+            base::options(global_options)
+
         if (stop.on.error && ERROR_OCCURRED) {
             UNEVALUATED
         } else {
