@@ -3,12 +3,14 @@
 ### -------------------------------------------------------------------------
 
 multicoreWorkers <- function()
-    .snowCores(multicore=TRUE)
+    .snowCores("multicore")
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Constructor 
 ###
 
+.MulticoreParam_prototype <- .SnowParam_prototype
+
 .MulticoreParam <- setRefClass("MulticoreParam",
     contains="SnowParam",
     fields=list(),
@@ -18,6 +20,7 @@ multicoreWorkers <- function()
 MulticoreParam <- function(workers=multicoreWorkers(), tasks=0L,  
         catch.errors=TRUE, stop.on.error=TRUE, 
         progressbar=FALSE, RNGseed=NULL, timeout= 30L * 24L * 60L * 60L,
+        exportglobals=TRUE,
         log=FALSE, threshold="INFO", logdir=NA_character_,
         resultdir=NA_character_, jobname = "BPJOB",
         manager.hostname=NA_character_, manager.port=NA_integer_, ...)
@@ -28,16 +31,41 @@ MulticoreParam <- function(workers=multicoreWorkers(), tasks=0L,
     if (!missing(catch.errors))
         warning("'catch.errors' is deprecated, use 'stop.on.error'")
 
-    args <- c(list(spec=workers, type="FORK"), list(...)) 
-    .MulticoreParam(.clusterargs=args, cluster=.NULLcluster(),
+    clusterargs <- c(list(spec=workers, type="FORK"), list(...))
+
+    manager.hostname <-
+        if (is.na(manager.hostname)) {
+            local <- (clusterargs$type == "FORK") ||
+                is.numeric(clusterargs$spec)
+            manager.hostname <- .snowHost(local)
+        } else as.character(manager.hostname)
+
+    manager.port <-
+        if (is.na(manager.port)) {
+            .snowPort(manager.hostname)
+        } else as.integer(manager.port)
+
+    if (!is.null(RNGseed))
+        RNGseed <- as.integer(RNGseed)
+
+    prototype <- .prototype_update(
+        .MulticoreParam_prototype,
+        .clusterargs=clusterargs, cluster=.NULLcluster(),
         .controlled=TRUE, workers=as.integer(workers), 
         tasks=as.integer(tasks),
         catch.errors=catch.errors, stop.on.error=stop.on.error, 
         progressbar=progressbar, 
-        RNGseed=RNGseed, timeout=timeout,
-        log=log, threshold=threshold, logdir=logdir,
-        resultdir=resultdir, jobname=jobname,
-        hostname=manager.hostname, port=manager.port)
+        RNGseed=RNGseed, timeout=as.integer(timeout),
+        exportglobals=exportglobals,
+        log=log, threshold=threshold,
+        logdir=logdir, resultdir=resultdir, jobname=jobname,
+        hostname=manager.hostname, port=manager.port,
+        ...
+    )
+
+    x <- do.call(.MulticoreParam, prototype)
+    validObject(x)
+    x
 }
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -48,8 +76,11 @@ setReplaceMethod("bpworkers", c("MulticoreParam", "numeric"),
     function(x, value)
 {
     value <- as.integer(value)
-    if (value > multicoreWorkers())
-        stop("'value' exceeds available workers detected by multicoreWorkers()")
+    max <- .snowCoresMax("multicore")
+    if (value > max)
+        stop(
+            "'value' exceeds ", max, " available workers; see ?multicoreWorkers"
+        )
  
     x$workers <- value 
     x$.clusterargs$spec <- value 
