@@ -4,19 +4,19 @@
 
 ## All params have dedicated bplapply methods.
 
-setMethod(bplapply, c("ANY", "missing"),
+setMethod("bplapply", c("ANY", "missing"),
     function(X, FUN, ..., BPREDO=list(), BPPARAM=bpparam())
 {
     FUN <- match.fun(FUN)
     bplapply(X, FUN, ..., BPREDO=BPREDO, BPPARAM=BPPARAM)
 })
 
-setMethod(bplapply, c("ANY", "list"),
+setMethod("bplapply", c("ANY", "list"),
     function(X, FUN, ..., BPREDO=list(), BPPARAM=bpparam())
 {
     FUN <- match.fun(FUN)
 
-    if (!all(vapply(BPPARAM, is, logical(1), "BiocParallelParam")))
+    if (!all(vapply(BPPARAM, inherits, logical(1), "BiocParallelParam")))
         stop("All elements in 'BPPARAM' must be BiocParallelParam objects")
     if (length(BPPARAM) == 0L)
         stop("'length(BPPARAM)' must be > 0")
